Task: SQuAD2
=============
Description: Open-domain QA dataset answerable from a given paragraph from Wikipedia, from Rajpurkar & Jia et al. '18. 

Link: http://arxiv.org/abs/1806.03822

Tags: #SQuAD2, #All, #QA

